@@ -1,6 +1,5 @@
 from controller import *
 from stream import Stream
-from operation_handler import OperationHandler
 from helper import Helper
 from base import Base
 from version import VERSION
@@ -23,19 +22,7 @@ class App(Base):
       Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"app", "multilang_version":VERSION}, self._socket)
 
   def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", prepare=None, begin_cycle=None, next_tuple=None):
-    op = OperationHandler(self, Stream)
-    streams = op.build_multilang_operation("source", name, matches, options, emits, end_cycle_policy, prepare, begin_cycle, next_tuple)\
-                       .add_operation_properties_to_info("name", "type")\
-                       .add_optional_operation_properties_to_info("relation", "matches", "end_cycle_policy")\
-                       .handle_operation()\
-                       .get_output_streams()
-    return streams
+    return Base._source_common(self, Stream, name, matches, options, emits, end_cycle_policy, prepare, begin_cycle, next_tuple)
 
-  def call_component(self, name=None, component_id=None, outputs=None, output_format="replace"):
-    op = OperationHandler(self, Stream)
-    op = op.build_multilang_operation("component", name, component_id, self, None, outputs, output_format)\
-           .add_operation_properties_to_info("name", "type", "id", "output_format")
-    node = op.node()
-    streams = op.handle_operation()\
-                .get_output_streams()
-    return streams
+  def call_component(self, *args, **kwargs):
+    return Base._call_component_common(self, None, Stream, *args, **kwargs)
